@@ -1,7 +1,7 @@
 package Getopt::Long::Complete;
 
 our $DATE = '2015-01-02'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,7 +30,7 @@ sub GetOptionsWithCompletion {
         $hash = shift;
         $ospec = { map {$_=>sub{}} @_ };
     } else {
-        $ospec = [@_];
+        $ospec = {@_};
     }
 
     my $shell;
@@ -106,7 +106,7 @@ Getopt::Long::Complete - A drop-in replacement for Getopt::Long, with shell tab
 
 =head1 VERSION
 
-This document describes version 0.22 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2015-01-02.
+This document describes version 0.23 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2015-01-02.
 
 =head1 SYNOPSIS
 
